This function and all of its descriptions have been obtained from the igraph package.
Usage
betweenness(
graph,
v = V(graph),
directed = TRUE,
weights = NULL,
normalized = FALSE,
...
)Arguments
- graph
The graph to analyze (an igraph graph).
- v
The vertices for which the vertex betweenness will be calculated.
- directed
Logical, whether directed paths should be considered while determining the shortest paths.
- weights
Optional positive weight vector for calculating weighted betweenness. If the graph has a weight edge attribute, then this is used by default. Weights are used to calculate weighted shortest paths, so they are interpreted as distances.
- normalized
Logical scalar, whether to normalize the betweenness scores. If TRUE, then the results are normalized.
- ...
Additional arguments according to the original
betweennessfunction in the package igraph.
See also
ivi,
cent_network.vis,
and betweenness for a complete description on this function
Other centrality functions:
clusterRank(),
collective.influence(),
h_index(),
lh_index(),
neighborhood.connectivity(),
sirir()
Examples
if (FALSE) { # \dontrun{
MyData <- coexpression.data
My_graph <- graph_from_data_frame(MyData)
GraphVertices <- V(My_graph)
My_graph_betweenness <- betweenness(My_graph, v = GraphVertices,
directed = FALSE,
normalized = FALSE)
} # }