Conditional probability of deviation from means
Source:R/cond-prob-analysis.R
cond.prob.analysis.RdThis function calculates the conditional probability of deviation of two centrality measures (or any two other continuous variables) from their corresponding means in opposite directions.
Arguments
- data
A data frame containing the values of two continuous variables and the name of observations (nodes).
- nodes.colname
The character format (quoted) name of the column containing the name of observations (nodes).
- Desired.colname
The character format (quoted) name of the column containing the values of the desired variable.
- Condition.colname
The character format (quoted) name of the column containing the values of the condition variable.
Value
A list of two objects including the conditional probability of deviation of two centrality measures (or any two other continuous variables) from their corresponding means in opposite directions based on both the entire network and the split-half random sample of network nodes.
See also
Other centrality association assessment functions:
double.cent.assess(),
double.cent.assess.noRegression()
Examples
if (FALSE) { # \dontrun{
MyData <- centrality.measures
My.conditional.prob <- cond.prob.analysis(data = MyData,
nodes.colname = rownames(MyData),
Desired.colname = "BC",
Condition.colname = "NC")
} # }