Neighborhood connectivity
Source:R/centrality-neighborhood-connectivity.R
neighborhood.connectivity.RdThis function calculates the neighborhood connectivity of input vertices and works with both directed and undirected networks.
Usage
neighborhood.connectivity(
graph,
vertices = V(graph),
mode = "all",
verbose = FALSE
)Arguments
- graph
A graph (network) of the igraph class.
- vertices
A vector of desired vertices, which could be obtained by the V function.
- mode
The mode of neighborhood connectivity depending on the directedness of the graph. If the graph is undirected, the mode "all" should be specified. Otherwise, for the calculation of neighborhood connectivity based on incoming connections select "in" and for the outgoing connections select "out". Also, if all of the connections are desired, specify the "all" mode. Default mode is set to "all".
- verbose
Logical; whether the accomplishment of different stages of the algorithm should be printed (default is FALSE).
See also
Other centrality functions:
betweenness(),
clusterRank(),
collective.influence(),
h_index(),
lh_index(),
sirir()
Examples
if (FALSE) { # \dontrun{
MyData <- coexpression.data
My_graph <- graph_from_data_frame(MyData)
GraphVertices <- V(My_graph)
neighrhood.co <- neighborhood.connectivity(graph = My_graph,
vertices = GraphVertices,
mode = "all")
} # }