This function calculates the local H-index of input vertices and works with both directed and undirected networks.
Usage
lh_index(
graph,
vertices = V(graph),
mode = "all",
ncores = "default",
verbose = FALSE
)Arguments
- graph
A graph (network) of the igraph class.
- vertices
A vector of desired vertices, which could be obtained by the V function.
- mode
The mode of local H-index depending on the directedness of the graph. If the graph is undirected, the mode "all" should be specified. Otherwise, for the calculation of local H-index based on incoming connections select "in" and for the outgoing connections select "out". Also, if all of the connections are desired, specify the "all" mode. Default mode is set to "all".
- ncores
Integer; the number of cores to be used for parallel processing. If ncores == "default" (default), the number of cores to be used will be the max(number of available cores) - 1. We recommend leaving ncores argument as is (ncores = "default").
- verbose
Logical; whether the accomplishment of different stages of the algorithm should be printed (default is FALSE).
See also
Other centrality functions:
betweenness(),
clusterRank(),
collective.influence(),
h_index(),
neighborhood.connectivity(),
sirir()
Examples
if (FALSE) { # \dontrun{
MyData <- coexpression.data
My_graph <- graph_from_data_frame(MyData)
GraphVertices <- V(My_graph)
lh.index <- lh_index(graph = My_graph, vertices = GraphVertices, mode = "all", ncores = 1)
} # }